==> 0.11.0.tar.gz: lib/acdart_shelf_middleware.dart <==
library ac_dart.shelf_middleware;

import 'src/auth.dart';
export 'src/auth.dart' show getSessionContext;

import 'package:shelf/shelf.dart';
import 'package:atlassian_connect_host/atlassian_connect_host.dart';
import 'dart:convert';
import 'dart:io';
import 'package:mustache/mustache.dart' as mustache;
import 'package:atlassian_connect_shelf/src/util.dart';
import 'package:option/option.dart';
import 'package:dart_jwt/dart_jwt.dart';
import 'package:atlassian_connect_jwt/atlassian_connect_jwt.dart';
import 'package:logging/logging.dart';

Middleware productHostAuthenticator(AcHostService hostService) =>
    new JwtAuthenticator(hostService).middleware;

Middleware sessionTokenAuthenticator(AcHostService hostService) =>
    new SessionTokenAuthenticator(hostService).middleware;

// TODO: this is not specific to connect. Look to move to third party lib
Handler moustacheFile(String path,
    {Map<String, dynamic> templateVariables: const {},
    bool includeHeaders: false, bool includeExtraParams: false}) {
  return (Request request) {
    final file = fileRelativeToAppRoot(path);
    return file
        .openRead()
        .transform(const Utf8Decoder())
        .fold(new StringBuffer(), (sb, s) => sb..write(s))
        .then((StringBuffer sb) {
      final tv = <String, dynamic>{}..addAll(templateVariables);
      if (includeHeaders || includeExtraParams) {
        // TODO: only untill extra params exist
        tv.addAll(request.headers);
      }
//        if (includeExtraParams) {
//          request.extraParams.forEach((k, v) {
//            if (v is String) {
//              tv[k] = v;
//            }
//          });
//        }
      final template = mustache.parse(sb.toString());
      final output = template.renderString(tv);
      return new Response.ok(output);
    });
  };
}

Handler staticFile(String path) {
//  new VirtualDirectory('../ui').
  return (Request request) {
    return new Response.ok(new File(path).openRead());
  };
}

Handler jwtTimingLogger(Handler innerHandler) {
  return (Request request) {
    final Option<String> jwtTokenOpt =
        new Option(request.requestedUri.queryParameters['jwt']);

    jwtTokenOpt.map((jwtToken) {
      final jwt = new JsonWebToken.decode(jwtToken,
          claimSetParser: (Map json) => new ProductHostClaimSet.fromJson(json));

      final ProductHostClaimSet claimSet = jwt.claimSet;
      final now = new DateTime.now();
      final iat = claimSet.issuedAt;
      final elapsed = now.difference(iat);
      _log.info(
          '${request.url.path}: received: $now; issued: $iat; elapsed: $elapsed');
    });

    return innerHandler(request);
  };
}

final Logger _log = new Logger('ac_dart.shelf_middleware');

==> 0.11.3.tar.gz: lib/acdart_shelf_middleware.dart <==
library ac_dart.shelf_middleware;

import 'src/auth.dart';
export 'src/auth.dart' show getPrincipal;

import 'package:shelf/shelf.dart';
import 'package:atlassian_connect_host/atlassian_connect_host.dart';
import 'dart:convert';
import 'dart:io';
import 'package:mustache/mustache.dart' as mustache;
import 'package:atlassian_connect_shelf/src/util.dart';
import 'package:option/option.dart';
import 'package:dart_jwt/dart_jwt.dart';
import 'package:atlassian_connect_jwt/atlassian_connect_jwt.dart';
import 'package:logging/logging.dart';
import 'package:shelf_auth/shelf_auth.dart';

@deprecated
Middleware productHostAuthenticator() => authenticate([new JwtAuthenticator()],
    sessionHandler: new SessionTokenSessionHandler(),
    allowAnonymousAccess: false,
    allowHttp: false);

@deprecated
Middleware sessionTokenAuthenticator() =>
    authenticate([new SessionTokenAuthenticator()],
        allowAnonymousAccess: false);

// TODO: this is not specific to connect. Look to move to third party lib
Handler moustacheFile(String path,
    {Map<String, dynamic> templateVariables: const {},
    bool includeHeaders: false,
    bool includeExtraParams: false}) {
  return (Request request) {
    final file = fileRelativeToAppRoot(path);
    return file
        .openRead()
        .transform(const Utf8Decoder())
        .fold(new StringBuffer(), (sb, s) => sb..write(s))
        .then((StringBuffer sb) {
      final tv = <String, dynamic>{}..addAll(templateVariables);
      if (includeHeaders || includeExtraParams) {
        // TODO: only until extra params exist
        tv.addAll(request.headers);
      }
//        if (includeExtraParams) {
//          request.extraParams.forEach((k, v) {
//            if (v is String) {
//              tv[k] = v;
//            }
//          });
//        }
      final template = mustache.parse(sb.toString());
      final output = template.renderString(tv);
      return new Response.ok(output);
    });
  };
}

Handler staticFile(String path) {
//  new VirtualDirectory('../ui').
  return (Request request) {
    return new Response.ok(new File(path).openRead());
  };
}

Handler jwtTimingLogger(Handler innerHandler) {
  return (Request request) {
    final Option<String> jwtTokenOpt =
        new Option(request.requestedUri.queryParameters['jwt']);

    jwtTokenOpt.map((jwtToken) {
      final jwt = new JsonWebToken.decode(jwtToken,
          claimSetParser: (Map json) => new ProductHostClaimSet.fromJson(json));

      final ProductHostClaimSet claimSet = jwt.claimSet;
      final now = new DateTime.now();
      final iat = claimSet.issuedAt;
      final elapsed = now.difference(iat);
      _log.info(
          '${request.url.path}: received: $now; issued: $iat; elapsed: $elapsed');
    });

    return innerHandler(request);
  };
}

final Logger _log = new Logger('ac_dart.shelf_middleware');
